@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Avoided;
 
 our $DATE = '2017-06-19'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 our @Module_Lists = (
     {
@@ -29,6 +29,11 @@ alternative called <pm:Log::ger>.
 _
                 alternate_modules => ['Log::ger'],
             },
+            {
+                module => 'Log::Any::IfLOG',
+                summary => 'Retired workaround',
+                alternate_modules => ['Log::ger'],
+            },
             {
                 module => 'File::Flock',
                 summary => 'Too many deps',
@@ -119,7 +124,7 @@ Acme::CPANLists::PERLANCAR::Avoided - Modules I'm currently avoiding
 
 =head1 VERSION
 
-This document describes version 0.21 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2017-06-19.
+This document describes version 0.22 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2017-06-19.
 
 =head1 MODULE LISTS
 
@@ -142,6 +147,10 @@ After the 1.x version, I no longer prefer L<Log::Any> and have developed an
 alternative called L<Log::ger>.
 
 
+Alternate modules: L<Log::ger>
+
+=item * L<Log::Any::IfLOG> - Retired workaround
+
 Alternate modules: L<Log::ger>
 
 =item * L<File::Flock> - Too many deps
